==> ametys-plugin-odf-pilotage-4.9.3.20251029-0049-b74-SNAPSHOT.jar: org/ametys/plugins/odfpilotage/report/impl/AbstractReport.java <==
/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.odfpilotage.report.impl;

import java.util.Map;

import org.xml.sax.ContentHandler;

import org.ametys.plugins.odfpilotage.report.AbstractPilotageReport;

/**
 * The abstract class for pilotage reports.
 */
public abstract class AbstractReport extends AbstractPilotageReport
{
    @Override
    protected boolean isSupportedTarget(PilotageReportTarget target)
    {
        return PilotageReportTarget.ORGUNIT.equals(target);
    }
    
    @Override
    protected PilotageReportContent getReportContentForProgram(String outputFormat, Map<String, String> reportParameters)
    {
        throw new UnsupportedOperationException("Impossible to launch the report '" + getType() + "' on a program.");
    }
    
    @Override
    protected PilotageReportContent getReportContentForOrgUnit(String outputFormat, Map<String, String> reportParameters)
    {
        return _getReportContentForOrgUnit(outputFormat, reportParameters);
    }
    
    @Override
    public void saxProgramItem(ContentHandler handler, String programItemId, Map<String, String> reportParameters)
    {
        throw new UnsupportedOperationException("Impossible to launch the report '" + getType() + "' on a program item.");
    }
}

==> ametys-plugin-odf-pilotage-4.9.5.20251220-0030-b102-SNAPSHOT.jar: org/ametys/plugins/odfpilotage/report/impl/AbstractReport.java <==
/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.plugins.odfpilotage.report.impl;

import java.util.Map;

import org.xml.sax.ContentHandler;

import org.ametys.plugins.odfpilotage.report.AbstractPilotageReport;

/**
 * The abstract class for pilotage reports.
 */
public abstract class AbstractReport extends AbstractPilotageReport
{
    @Override
    protected boolean isSupportedTarget(PilotageReportTarget target)
    {
        return PilotageReportTarget.ORGUNIT.equals(target);
    }
    
    @Override
    protected PilotageReportContent getReportContentForProgram(String outputFormat, Map<String, String> reportParameters)
    {
        throw new UnsupportedOperationException("Impossible to launch the report '" + getType(reportParameters, true) + "' on a program.");
    }
    
    @Override
    protected PilotageReportContent getReportContentForOrgUnit(String outputFormat, Map<String, String> reportParameters)
    {
        return _getReportContentForOrgUnit(outputFormat, reportParameters);
    }
    
    @Override
    public void saxProgramItem(ContentHandler handler, String programItemId, Map<String, String> reportParameters)
    {
        throw new UnsupportedOperationException("Impossible to launch the report '" + getType(reportParameters, true) + "' on a program item.");
    }
}
